screen_loading_handler library

Classes

ScreenLoadingHandler
The ScreenLoadingHandler widget displays a loading box (spinner) over the body of the screen when the loading state is triggered. It listens to a ScreenLoadingController which manages the loading state using a ValueNotifier. The widget will automatically rebuild and display the loading indicator without requiring manual calls to setState.